caellion-python-commons: tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText Class Reference

caellion-python-commons

Public Member Functions | List of all members
tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText Class Reference

## Public Member Functions
def | test_upt_duplicate_keynames (self)
def | test_upt_empty_keyname (self)
def | test_upt_none_keyname (self)
def | test_upt_empty_separator (self)
def | test_upt_none_separator (self)
def | test_upt_empty_newline (self)
def | test_upt_none_newline (self)
def | test_upt_invalid_line (self)
def | test_upt_invalid_block (self)
def | test_upt_parse_line_ok (self, arg, expected)
def | test_upt_create_line_ok (self, arg, expected)
def | test_upt_add_new_line_ok (self, arg)
def | test_upt_add_line_from_text_ok (self, arg)
def | test_dump_text_ok (self)
def | test_load_then_dump_text_ok (self)

## Detailed Description

Definition at line 15 of file test_stringutil_unixpassword.py.

## Member Function Documentation

## ◆ test_dump_text_ok()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_dump_text_ok | ( |  | self | ) |

Definition at line 116 of file test_stringutil_unixpassword.py.

## ◆ test_load_then_dump_text_ok()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_load_then_dump_text_ok | ( |  | self | ) |

Definition at line 122 of file test_stringutil_unixpassword.py.

## ◆ test_upt_add_line_from_text_ok()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_add_line_from_text_ok | ( |  | self,
|  |  | arg
| ) |  |

Definition at line 109 of file test_stringutil_unixpassword.py.

## ◆ test_upt_add_new_line_ok()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_add_new_line_ok | ( |  | self,
|  |  | arg
| ) |  |

Definition at line 95 of file test_stringutil_unixpassword.py.

## ◆ test_upt_create_line_ok()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_create_line_ok | ( |  | self,
|  |  | arg,
|  |  | expected
| ) |  |

Definition at line 83 of file test_stringutil_unixpassword.py.

## ◆ test_upt_duplicate_keynames()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_duplicate_keynames | ( |  | self | ) |

Definition at line 20 of file test_stringutil_unixpassword.py.

## ◆ test_upt_empty_keyname()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_empty_keyname | ( |  | self | ) |

Definition at line 24 of file test_stringutil_unixpassword.py.

## ◆ test_upt_empty_newline()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_empty_newline | ( |  | self | ) |

Definition at line 40 of file test_stringutil_unixpassword.py.

## ◆ test_upt_empty_separator()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_empty_separator | ( |  | self | ) |

Definition at line 32 of file test_stringutil_unixpassword.py.

## ◆ test_upt_invalid_block()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_invalid_block | ( |  | self | ) |

Definition at line 53 of file test_stringutil_unixpassword.py.

## ◆ test_upt_invalid_line()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_invalid_line | ( |  | self | ) |

Definition at line 48 of file test_stringutil_unixpassword.py.

## ◆ test_upt_none_keyname()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_none_keyname | ( |  | self | ) |

Definition at line 28 of file test_stringutil_unixpassword.py.

## ◆ test_upt_none_newline()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_none_newline | ( |  | self | ) |

Definition at line 44 of file test_stringutil_unixpassword.py.

## ◆ test_upt_none_separator()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_none_separator | ( |  | self | ) |

Definition at line 36 of file test_stringutil_unixpassword.py.

## ◆ test_upt_parse_line_ok()

def tests.test_stringutil_unixpassword.TestStringUtilUnixPasswordText.test_upt_parse_line_ok | ( |  | self,
|  |  | arg,
|  |  | expected
| ) |  |

Definition at line 68 of file test_stringutil_unixpassword.py.

The documentation for this class was generated from the following file:

- tests/test_stringutil_unixpassword.py